@@ -25,8 +25,9 @@ class BlobReader:
     input_container = "input"
     output_container = "output"
 
-    def __init__(self, return_only_source):
+    def __init__(self, connection_string, return_only_source):
         self.return_only_source = return_only_source
+        self.connection_string = connection_string
 
     def read_blob_by_segments(self, blob_name: str):
         blob = self.get_input_blob(blob_name)
@@ -148,7 +149,7 @@ class MetadataRepository:
         trace = traceback.format_exc()[:MAX_PROP_SIZE]
         error = str(e)[:MAX_PROP_SIZE]
         entity = {"PartitionKey": worker_name, "RowKey": request_id, "FailureMessage": error, "StackTrace": trace}
-        self.table_client.insert_entity(self.failure_table, entity)
+        self.table_client.insert_or_replace_entity(self.failure_table, entity)
 
     def record_segment_failures(self, request_id, worker_name, failures):
         batch, count = TableBatch(), 0
@@ -255,7 +256,7 @@ class Worker:
         self.worker_name = worker_name
         self.segment_limit = segment_limit
 
-        self.reader = BlobReader(return_only_source)
+        self.reader = BlobReader(connection_string, return_only_source)
         self.metadata_repository = MetadataRepository(connection_string, worker_name + "Data", create_if_not_exist)
         self.message_queue_client = MessageQueueClient(worker_name.lower(), worker_name.lower() + "-poison", connection_string, create_if_not_exist)
         self.pool = ThreadPool(processes=1)
